@@ -68,6 +68,11 @@ class Shelf(dict):
         """
         raise NotImplementedError
 
+    def schema(self):
+        """
+        Get the schema used to sort the items
+        """
+
 class ShelfOfShelves(Shelf):
     """
     This Shelf is made of shelves. We will thread and assemble all queries. The shelf of shelves
@@ -133,3 +138,13 @@ class ShelfOfShelves(Shelf):
                 results.upgrade_and_extend(shelf.search(query))
 
         return results
+
+    def schema(self):
+        """
+        Let's get the schema of all the shelves we have
+        """
+        schemas = {}
+        for shelf in library:
+            schemas.update(shelf.schema())
+
+        return schemas
